<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>QObject</name>
    <message>
        <location filename="../qsynthOptions.cpp" line="173"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="175"/>
        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
        <translation>Не создавать драйвер MIDI для чтения входящих событий MIDI [по умолчанию = yes]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="177"/>
        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
        <translation>Имя используемого драйвера MIDI [oss,alsa,alsa_seq,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="179"/>
        <source>The number of midi channels [default = 16]</source>
        <translation>Количество каналов MIDI [по умолчанию = 16]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="181"/>
        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
        <translation>Звуковой драйвер [alsa,jack,oss,dsound,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="183"/>
        <source>Attempt to connect the jack outputs to the physical ports</source>
        <translation>Попытка связать выход JACK с физическими портами</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="185"/>
        <source>The number of stereo audio channels [default = 1]</source>
        <translation>Количество стереофонических звуковых каналов [по умолчанию = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="187"/>
        <source>The number of audio groups [default = 1]</source>
        <translation>Количиство звуковых групп [по умолчанию = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="189"/>
        <source>Size of each audio buffer</source>
        <translation>Размер каждого звукового буфера</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="191"/>
        <source>Number of audio buffers</source>
        <translation>Количество звуковых буферов</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="193"/>
        <source>Set the sample rate</source>
        <translation>Установить частоту семплирования</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="195"/>
        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Включить/выключить реверберацию [1|0|yes|no|on|off, по умолчанию = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="197"/>
        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Включить/выключить хорус [1|0|yes|no|on|off, по умолчанию = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="199"/>
        <source>Set the master gain [0 &lt; gain &lt; 10, default = 0.2]</source>
        <translation>Установить главное усиление [0 &lt; усиление &lt; 10, по умолчанию = 0.2]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="201"/>
        <source>Define a setting name=value</source>
        <translation>Определите имя=значение настройки</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="203"/>
        <source>Create and start server [default = no]</source>
        <translation>Создать и запустить сервер [по умолчанию = no]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="205"/>
        <source>Don&apos;t read commands from the shell [ignored]</source>
        <translation>Не считывать команды из оболочки [проигнорировано]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="207"/>
        <source>Dump midi router events</source>
        <translation>Глушить события маршрутизатора MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="209"/>
        <source>Print out verbose messages about midi events</source>
        <translation>Показывать подробную информацию о сообщениях MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="211"/>
        <source>Show help about command line options</source>
        <translation>Показать справку о параметрах для командной строки</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="213"/>
        <source>Show version information</source>
        <translation>Показать информацию о версии</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="245"/>
        <source>Option -m requires an argument (midi-driver).</source>
        <translation>Ключ -m требует аргумента (midi-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="254"/>
        <source>Option -K requires an argument (midi-channels).</source>
        <translation>Ключ -K требует аргумента (midi-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="263"/>
        <source>Option -a requires an argument (audio-driver).</source>
        <translation>Ключ -a требует аргумента (audio-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="275"/>
        <source>Option -L requires an argument (audio-channels).</source>
        <translation>Ключ -L требует аргумента (audio-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="284"/>
        <source>Option -G requires an argument (audio-groups).</source>
        <translation>Ключ -G требует аргумента (audio-groups).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="293"/>
        <source>Option -z requires an argument (audio-bufsize).</source>
        <translation>Ключ -a требует аргумента (audio-bufsize).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="302"/>
        <source>Option -c requires an argument (audio-bufcount).</source>
        <translation>Ключ -c требует аргумента (audio-bufcount).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="311"/>
        <source>Option -r requires an argument (sample-rate).</source>
        <translation>Ключ -r требует аргумента (sample-rate).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="338"/>
        <source>Option -g requires an argument (gain).</source>
        <translation>Ключ -g требует аргумента (gain).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="347"/>
        <source>Option -o requires an argument.</source>
        <translation>Ключ -o требует аргумента.</translation>
    </message>
    <message>
        <location filename="../qsynthSetup.cpp" line="37"/>
        <source>(default)</source>
        <translation>(по умолчанию)</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="170"/>
        <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
        <translation>Использование: %1 [ключи] [файлы SF2] [файлы MIDI]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="369"/>
        <source>Qt: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="371"/>
        <source>%1: %2  (%3)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="392"/>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>неизвестный ключ &apos;%1&apos;.</translation>
    </message>
</context>
<context>
    <name>qsynthAboutForm</name>
    <message>
        <location filename="../qsynthAboutForm.ui" line="71"/>
        <source>About Qt</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="61"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="43"/>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="44"/>
        <source>Build</source>
        <translation>Сборка</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="53"/>
        <source>System tray disabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="58"/>
        <source>Server option disabled.</source>
        <translation>Параметр сервера отключен.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="75"/>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="80"/>
        <source>This program is free software; you can redistribute it and/or modify it</source>
        <translation>Эта программа является свободной; вы имеете право распространять и/или</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="81"/>
        <source>under the terms of the GNU General Public License version 2 or later.</source>
        <translation>изменять её на условиях лицензии GNU GPL версии 2 или более новой.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="47"/>
        <source>Debugging option enabled.</source>
        <translation>Параметр отладки включён.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="64"/>
        <source>System reset option disabled.</source>
        <translation>Параметр перезагрузки системы включён.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="70"/>
        <source>Bank offset option disabled.</source>
        <translation>Функция смещения банка отключена.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="33"/>
        <source>About Qsynth</source>
        <translation>О Qsynth</translation>
    </message>
</context>
<context>
    <name>qsynthChannelsForm</name>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="333"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="342"/>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="56"/>
        <source>Preset &amp;Name:</source>
        <translation>Имя &amp;предустановки:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="84"/>
        <source>(default)</source>
        <translation>(по умолчанию)</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="77"/>
        <source>Settings preset name</source>
        <translation>Имя предустановки настроек</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="95"/>
        <source>&amp;Save</source>
        <translation>Со&amp;хранить</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="92"/>
        <source>Save settings as current preset name</source>
        <translation>Сохранить настройки в текущую предустановку</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="111"/>
        <source>&amp;Delete</source>
        <translation>У&amp;далить</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="108"/>
        <source>Delete current settings preset</source>
        <translation>Удалить текущую предустановку</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="168"/>
        <source>In</source>
        <translation>Вх</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="178"/>
        <source>Bank</source>
        <translation>Банк</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="183"/>
        <source>Prog</source>
        <translation>Программа</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="188"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="193"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="198"/>
        <source>Soundfont</source>
        <translation>SF2-файл</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="143"/>
        <source>Channels view</source>
        <translation>Вид каналов</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="172"/>
        <source>Channels</source>
        <translation>Каналы</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="338"/>
        <source>Unset</source>
        <translation>Снять</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="470"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="471"/>
        <source>Delete preset:</source>
        <translation>Удалить пресет:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="473"/>
        <source>Are you sure?</source>
        <translation>Вы уверены?</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="36"/>
        <source>Qsynth: Channels</source>
        <translation>qsynth: Каналы</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="173"/>
        <source>Chan</source>
        <translation>Канал</translation>
    </message>
</context>
<context>
    <name>qsynthMainForm</name>
    <message>
        <location filename="../qsynthMainForm.ui" line="456"/>
        <source>Chorus</source>
        <translation>Хор</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="619"/>
        <location filename="../qsynthMainForm.ui" line="666"/>
        <source>Chorus Level</source>
        <translation>Громкость хора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="644"/>
        <source>Le&amp;vel</source>
        <translation>Гро&amp;мк.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="785"/>
        <source>Dept&amp;h</source>
        <translation>Глу&amp;бина</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="509"/>
        <source>T&amp;ype:</source>
        <translation>&amp;Тип:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="484"/>
        <source>Sine</source>
        <translation>Синусоида</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="489"/>
        <source>Triangle</source>
        <translation>Треугольная</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="480"/>
        <source>Chorus Modulation Type</source>
        <translation>Тип модуляции хора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="149"/>
        <source>Reverb</source>
        <translation>Реверберация</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="340"/>
        <source>D&amp;amp</source>
        <translation>При&amp;глуш.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="387"/>
        <location filename="../qsynthMainForm.ui" line="428"/>
        <source>Reverb Room Size</source>
        <translation>Объём помещения</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="406"/>
        <source>R&amp;oom</source>
        <translation>&amp;Комната</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="233"/>
        <source>&amp;Level</source>
        <translation>&amp;Громк.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="176"/>
        <source>Ac&amp;tive</source>
        <translation>&amp;Вкл</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="853"/>
        <location filename="../qsynthMainForm.cpp" line="1162"/>
        <source>&amp;Quit</source>
        <translation>В&amp;ыйти</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="850"/>
        <source>Quit this application</source>
        <translation>Выйти из программы</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="964"/>
        <location filename="../qsynthMainForm.cpp" line="1129"/>
        <location filename="../qsynthMainForm.cpp" line="1611"/>
        <source>Set&amp;up...</source>
        <translation>&amp;Настроить...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="885"/>
        <location filename="../qsynthMainForm.cpp" line="1152"/>
        <source>&amp;Messages</source>
        <translation>&amp;Сообщения</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="882"/>
        <source>Show/hide the messages log window</source>
        <translation>Показать/скрыть окно отображения сообщений программы</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="904"/>
        <source>A&amp;bout...</source>
        <translation>О &amp;программе...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="901"/>
        <source>Show information about this application</source>
        <translation>Показать информацию об этом приложении</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="49"/>
        <source>Master</source>
        <translation>Мастер</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="89"/>
        <location filename="../qsynthMainForm.ui" line="114"/>
        <source>Master Gain</source>
        <translation>Общее усиление</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="67"/>
        <source>&amp;Gain</source>
        <translation>&amp;Усиление</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="951"/>
        <location filename="../qsynthMainForm.cpp" line="1117"/>
        <source>&amp;Reset</source>
        <translation>С&amp;бросить</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="948"/>
        <source>Program reset (all channels)</source>
        <translation>Сброс программ (все каналы)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="130"/>
        <source>Complete engine restart</source>
        <translation>Полная перезагрузка синтезатора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="712"/>
        <location filename="../qsynthMainForm.cpp" line="1326"/>
        <location filename="../qsynthMainForm.cpp" line="2084"/>
        <location filename="../qsynthMainForm.cpp" line="2114"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="715"/>
        <location filename="../qsynthMainForm.cpp" line="1329"/>
        <source>Are you sure?</source>
        <translation>Вы уверены?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="994"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2087"/>
        <location filename="../qsynthMainForm.cpp" line="2118"/>
        <source>Please note that this operation may cause
temporary MIDI and Audio disruption.</source>
        <translation>Обратите внимание на то, что выполнение
этой операции может привести к временным
сбоям в воспроизведении MIDI и аудио.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2120"/>
        <source>Do you want to restart the engine now?</source>
        <translation>Вы хотите перезагрузить движок синтезатора?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1746"/>
        <source>Creating synthesizer engine</source>
        <translation>Создается движок синтезатора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1862"/>
        <source>Creating MIDI player</source>
        <translation>Создается проигрыватель MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1876"/>
        <source>Creating server</source>
        <translation>Создается сервер</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1936"/>
        <source>Synthesizer engine started.</source>
        <translation>Движок синтезатора запущен</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1976"/>
        <source>Destroying server</source>
        <translation>Выполняется разрушение сервера</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1984"/>
        <source>Stopping MIDI player</source>
        <translation>Останавливается устройство воспроизведения MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1986"/>
        <source>Waiting for MIDI player to terminate</source>
        <translation>Ожидается выгрузка устройства воспроизведения MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1988"/>
        <source>Destroying MIDI player</source>
        <translation>Выполняется разрушение проигрывателя MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1996"/>
        <source>Destroying MIDI driver</source>
        <translation>Выполняется разрушение драйвера MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2000"/>
        <source>Destroying MIDI router</source>
        <translation>Выполняется разрушение маршрутизатора MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2007"/>
        <source>Destroying audio driver</source>
        <translation>Выполняется разрушение звукового драйвера</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2033"/>
        <source>Destroying synthesizer engine</source>
        <translation>Разрушается движок синтезатора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2037"/>
        <source>Synthesizer engine terminated.</source>
        <translation>Движок синтезатора остановлен</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="671"/>
        <location filename="../qsynthMainForm.cpp" line="1502"/>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1504"/>
        <source>Some settings will be only effective
next time you start this program.</source>
        <translation>Некоторые изменения будут учтены только 
при следующей загрузке программы.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1032"/>
        <source>Engine selector (right-click for menu)</source>
        <translation>Выбор движка (меню под правой клавишей мыши)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="133"/>
        <location filename="../qsynthMainForm.cpp" line="1115"/>
        <location filename="../qsynthMainForm.cpp" line="1212"/>
        <source>Re&amp;start</source>
        <translation>Пере&amp;запустить</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="938"/>
        <location filename="../qsynthMainForm.cpp" line="1120"/>
        <source>&amp;Panic</source>
        <translation>&amp;Паника</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="935"/>
        <source>System reset</source>
        <translation>Перезагрузка системы</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="685"/>
        <location filename="../qsynthMainForm.ui" line="738"/>
        <source>Chorus Speed (Hz)</source>
        <translation>Скорость хора (Гц)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="716"/>
        <source>Spee&amp;d</source>
        <translation>&amp;Скорость</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="713"/>
        <source>Chorus Speed Hz</source>
        <translation>Скорость хора (Гц)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="553"/>
        <location filename="../qsynthMainForm.ui" line="600"/>
        <source>Number of Chorus Stages</source>
        <translation>Число стадий хора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="578"/>
        <source>&amp;N</source>
        <translation>&amp;N</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="760"/>
        <location filename="../qsynthMainForm.ui" line="807"/>
        <source>Chorus Depth (ms)</source>
        <translation>Глубина хора (мс)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="540"/>
        <source>Act&amp;ive</source>
        <translation>Вк&amp;л</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="537"/>
        <source>Chorus effect activation</source>
        <translation>Включение эффект хора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="980"/>
        <location filename="../qsynthMainForm.cpp" line="1124"/>
        <source>&amp;Channels</source>
        <translation>&amp;Каналы</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="977"/>
        <source>Show/hide the channels view window</source>
        <translation>Переключить отображение окна каналов</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="321"/>
        <location filename="../qsynthMainForm.ui" line="362"/>
        <source>Reverb Damp Factor</source>
        <translation>Фактор затухания реверберации</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="255"/>
        <location filename="../qsynthMainForm.ui" line="296"/>
        <source>Reverb Width</source>
        <translation>Ширина стереобазы</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="274"/>
        <source>&amp;Width</source>
        <translation>&amp;Ширина</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="189"/>
        <location filename="../qsynthMainForm.ui" line="208"/>
        <source>Reverb Level</source>
        <translation>Громкость реверберации</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="173"/>
        <source>Reverb effect activation</source>
        <translation>Включение эффекта хора</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="961"/>
        <source>Show instance settings and configuration dialog</source>
        <translation>Показать параметры запущенной копии 
движка синтезатора и диалог настройки</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="869"/>
        <location filename="../qsynthMainForm.cpp" line="1156"/>
        <source>&amp;Options...</source>
        <translation>&amp;Параметры...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="866"/>
        <source>Show general options dialog</source>
        <translation>Показать главный диалог настройки параметров</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="714"/>
        <source>is about to terminate.</source>
        <translation>собирается завершить работу.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="725"/>
        <source>Don&apos;t ask this again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1115"/>
        <location filename="../qsynthMainForm.cpp" line="1214"/>
        <source>&amp;Start</source>
        <translation>&amp;Запустить</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1327"/>
        <source>Delete fluidsynth engine:</source>
        <translation>Удалить движок fluidsynth:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2115"/>
        <source>New settings will be effective after
restarting the fluidsynth engine:</source>
        <translation>Некоторые изменения будут учтены только
после перезагрузки движка fluidsynth:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="673"/>
        <source>The program will keep running in the system tray.

To terminate the program, please choose &quot;Quit&quot;
in the context menu of the system tray icon.</source>
        <translation>Программа продолджит работу в области уведомления.

Для завершения работы с ней выберите пункт «Выход»
в контекстном меню элемента области уведомления.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="689"/>
        <source>Don&apos;t show this message again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="805"/>
        <source>Loading soundfont: &quot;%1&quot;</source>
        <translation>Загружается файл SF2: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="816"/>
        <location filename="../qsynthMainForm.cpp" line="1787"/>
        <source>Failed to load the soundfont: &quot;%1&quot;.</source>
        <translation>Не удалось загрузить файл SF2: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="824"/>
        <source>Playing MIDI file: &quot;%1&quot;</source>
        <translation>Воспроизводится файл MIDI: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="831"/>
        <source>Failed to play MIDI file: &quot;%1&quot;.</source>
        <translation>Не удалось воспроизвести файл MIDI: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1097"/>
        <source>&amp;Hide</source>
        <translation>С&amp;крыть</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1093"/>
        <source>Mi&amp;nimize</source>
        <translation>Св&amp;ернуть</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1098"/>
        <source>S&amp;how</source>
        <translation>&amp;Показать</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1094"/>
        <source>Rest&amp;ore</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1107"/>
        <location filename="../qsynthMainForm.cpp" line="1605"/>
        <source>&amp;New engine...</source>
        <translation>&amp;Создать движок...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1109"/>
        <location filename="../qsynthMainForm.cpp" line="1607"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1135"/>
        <source>Engines</source>
        <translation>Движки</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1750"/>
        <source>Failed to create the synthesizer.

Cannot continue without it.</source>
        <translation>Не удалось создать синтезатор.

Продолжение без него невозможно.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1781"/>
        <source>Loading soundfont: &quot;%1&quot; (bank offset %2)</source>
        <translation>Загружается файл SF2: &quot;%1&quot; (смещение банка %2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1794"/>
        <source>Failed to set bank offset (%1) for soundfont: &quot;%2&quot;.</source>
        <translation>Не удалось задать смещение банка (%1) для файла &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1804"/>
        <source>Creating audio driver (%1)</source>
        <translation>Создается звуковой драйвер (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1818"/>
        <source>Failed to create the audio driver (%1).

Cannot continue without it.</source>
        <translation>Не удалось создать звуковой драйвер (%1).

Продолжение без него невозможно.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1831"/>
        <source>Creating MIDI router (%1)</source>
        <translation>Создается маршрутизатор MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1840"/>
        <source>Failed to create the MIDI input router (%1).

No MIDI input will be available.</source>
        <translation>Не удалось создать входящий маршрутизатор MIDI (%1).

Вход MIDI будет недоступен.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1846"/>
        <source>Creating MIDI driver (%1)</source>
        <translation>Создается драйвер MIDI (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1855"/>
        <source>Failed to create the MIDI driver (%1).

No MIDI input will be available.</source>
        <translation>Не удалось создать драйвер MIDI (%1).

Вход MIDI будет недоступен.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1866"/>
        <source>Failed to create the MIDI player.

Continuing without a player.</source>
        <translation>Не удалось создать проигрыватель MIDI.

Придется обойтись без проигрывателя.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1898"/>
        <source>Failed to create the server.

Continuing without it.</source>
        <translation>Не удалось создать сервер.

Придется обойтись без сервера.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1902"/>
        <source>Server mode disabled.

Continuing without it.</source>
        <translation>Режим сервера выключен.

Придется обойтись без сервера.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2022"/>
        <source>Unloading soundfont: &quot;%1&quot; (SFID=%2)</source>
        <translation>Выгружается файл SF2: &quot;%1&quot; (SFID=%2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2026"/>
        <source>Failed to unload the soundfont: &quot;%1&quot;.</source>
        <translation>Не удалось выгрузить файл SF2: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2085"/>
        <source>New settings will be effective after
restarting all fluidsynth engines.</source>
        <translation>Некоторые изменения будут учтены только
после перезагрузки всех движков fluidsynth.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2089"/>
        <source>Do you want to restart all engines now?</source>
        <translation>Вы хотите перезапустить все движки?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="34"/>
        <source>Qsynth - A fluidsynth Qt GUI Interface</source>
        <translation>Qsynth — интерфейс к FluidSynth</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1019"/>
        <source>Add a new engine</source>
        <translation>Добавить новый движок</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1070"/>
        <source>Delete current engine</source>
        <translation>Удалить активный движок</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="832"/>
        <source>Output peak level</source>
        <translation>Индикатор уровня громкости</translation>
    </message>
</context>
<context>
    <name>qsynthMessagesForm</name>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="54"/>
        <source>Messages output log</source>
        <translation>Журнал сообщений Qsynth</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="136"/>
        <source>Logging stopped --- %1 ---</source>
        <translation>Журналирование остановлено --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="146"/>
        <source>Logging started --- %1 ---</source>
        <translation>Журналирование начато --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="42"/>
        <source>Qsynth: Messages</source>
        <translation>Qsynth: Сообщения</translation>
    </message>
</context>
<context>
    <name>qsynthOptionsForm</name>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="43"/>
        <source>Display</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="82"/>
        <source>Sample messages text font display</source>
        <translation>Шрифт для отображения сообщения</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="113"/>
        <source>&amp;Font...</source>
        <translation>&amp;Шрифт...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="110"/>
        <source>Select font for the messages text display</source>
        <translation>Выберите шрифт для отображения сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="148"/>
        <source>&amp;Messages limit:</source>
        <translation>&amp;Строк сообщений:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="145"/>
        <source>Whether to keep a maximum number of lines in the messages window</source>
        <translation>Сохранять ли максимально возможное 
количество строк сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="171"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="176"/>
        <source>250</source>
        <translation>250</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="181"/>
        <source>500</source>
        <translation>500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="186"/>
        <source>1000</source>
        <translation>1000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="191"/>
        <source>2500</source>
        <translation>2500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="196"/>
        <source>5000</source>
        <translation>5000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="161"/>
        <source>The maximum number of message lines to keep in view</source>
        <translation>Максимальное количество 
показываемых строк сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="440"/>
        <source>Other</source>
        <translation>Другое</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="458"/>
        <source>&amp;Confirm application close</source>
        <translation>&amp;Запрашивать подтверждение на выход из программы</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="455"/>
        <source>Whether to ask for confirmation on application exit</source>
        <translation>Запрашивать ли подтверждение 
на выход из приложения</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="474"/>
        <source>&amp;Keep child windows always on top</source>
        <translation>&amp;Держать подчинённые окна всегда наверху</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="471"/>
        <source>Whether to keep all child windows on top of the main window</source>
        <translation>Держать ли подчинённые окна над 
основным окном программы</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="490"/>
        <source>Capture standard &amp;output</source>
        <translation>Захватывать стандартный интерфейс &amp;вывода сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="487"/>
        <source>Whether to capture standard output (stdout/stderr) into messages window</source>
        <translation>Захватывать ли стандартный интерфейс вывода 
сообщений (stdout/stderr) для  окна сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="246"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="248"/>
        <source>Do you want to apply the changes?</source>
        <translation>Вы хотите учесть изменения?</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="247"/>
        <source>Some options have been changed.</source>
        <translation>Некоторые параметры были изменены.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="307"/>
        <source>Messages Log</source>
        <translation>Журнал сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="309"/>
        <source>Log files</source>
        <translation>Файлы журналов</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="33"/>
        <source>Qsynth: Options</source>
        <translation>Qsynth: Общие параметры</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="55"/>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="213"/>
        <source>Logging</source>
        <translation>Журналирование</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="236"/>
        <source>Messages log file</source>
        <translation>Файл журнала сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="267"/>
        <source>Browse for the messages log file location</source>
        <translation>Укажите каталог для хранения файла с журналом сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="270"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="283"/>
        <source>Whether to activate a messages logging to file.</source>
        <translation>Записывать ли журнал сообщений в файл</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="286"/>
        <source>Messages &amp;log file:</source>
        <translation>&amp;Файл журнала сообщений:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="302"/>
        <source>Knobs</source>
        <translation>Кнопки</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="317"/>
        <source>Kno&amp;b graphic style:</source>
        <translation>&amp;Стиль оформления кнопок:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="333"/>
        <source>Graphic style for knobs</source>
        <translation>Стиль оформления кнопок</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="337"/>
        <source>Classic</source>
        <translation>Классический</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="342"/>
        <source>Vokimon</source>
        <translation>Вокимон</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="347"/>
        <source>Peppino</source>
        <translation>Пеппино</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="352"/>
        <source>Skulpture</source>
        <translation>Скульптура</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="357"/>
        <location filename="../qsynthOptionsForm.ui" line="413"/>
        <source>Legacy</source>
        <translation>Прежний</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="387"/>
        <source>Mouse motion be&amp;havior:</source>
        <translation>Поведение при вращении &amp;мышью:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="406"/>
        <source>Mouse motion behavior for knobs</source>
        <translation>Поведение кнопок при вращении их мышью</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="418"/>
        <source>Radial</source>
        <translation>Радиальное</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="423"/>
        <source>Linear</source>
        <translation>Линейное</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="503"/>
        <source>Whether to monitor and show engine output peak level meters</source>
        <translation>Показывать ли индикатор уровня громкости движка</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="506"/>
        <source>Output &amp;peak level meters</source>
        <translation>Включить &amp;индикатор уровня громкости</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="548"/>
        <source>Whether to show system tray message on main window close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="551"/>
        <source>Sho&amp;w system tray message on close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="599"/>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="532"/>
        <source>Whether to enable the system tray icon</source>
        <translation>Включать ли значок в области уведомления</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="535"/>
        <source>&amp;Enable system tray icon</source>
        <translation>&amp;Использовать область уведомления</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="564"/>
        <source>Whether to start minimized to system tray</source>
        <translation>Убирать ли окно в область уведомления</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="567"/>
        <source>Start minimi&amp;zed to system tray</source>
        <translation>&amp;При старте скрывать окно в область уведомления</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="636"/>
        <source>&amp;Base font size:</source>
        <translation>&amp;Кегль шрифта в GUI:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="655"/>
        <source>Base application font size (pt.)</source>
        <translation>Кегль шрифта в интерфейсе приложения (пункты)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="662"/>
        <source>(default)</source>
        <translation>(по умолчанию)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="667"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="672"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="677"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="682"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="687"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="692"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="697"/>
        <source>12</source>
        <translation>12</translation>
    </message>
</context>
<context>
    <name>qsynthPresetForm</name>
    <message>
        <location filename="../qsynthPresetForm.ui" line="59"/>
        <source>Preset</source>
        <translation>Предустановка</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="143"/>
        <source>Prog</source>
        <translation>Прогр.</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="148"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="153"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="158"/>
        <source>Soundfont</source>
        <translation>Soundfont</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="118"/>
        <source>Program selector</source>
        <translation>Выбор программы</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="112"/>
        <source>Bank</source>
        <translation>Банк</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="87"/>
        <source>Bank selector</source>
        <translation>Выбор банка</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="170"/>
        <source>Preview</source>
        <translation>Прослушать</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="167"/>
        <source>Whether to preview the current selection</source>
        <translation>Просматривать ли текущее выделение</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.cpp" line="147"/>
        <source>Channel %1</source>
        <translation>Канал %1</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="33"/>
        <source>Qsynth: Channel Preset</source>
        <translation>Qsynth: Предустановка канала</translation>
    </message>
</context>
<context>
    <name>qsynthSetupForm</name>
    <message>
        <location filename="../qsynthSetupForm.ui" line="144"/>
        <source>Enable MIDI &amp;Input</source>
        <translation>Разрешить чтение &amp;событий MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="141"/>
        <source>Enable MIDI input</source>
        <translation>Разрешить чтение событий MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="118"/>
        <source>&amp;Dump MIDI router events</source>
        <translation>&amp;Глушить события маршрутизатора MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="115"/>
        <source>Whether to show MIDI router events on messages window</source>
        <translation>Показывать ли события маршрутизатора MIDI в окне сообщений</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="180"/>
        <source>&amp;Verbose MIDI event messages</source>
        <translation>&amp;Подробный вывод сообщений MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="177"/>
        <source>Print out verbose messages about MIDI events</source>
        <translation>Показывать подробную информацию о сообщениях MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="99"/>
        <source>&amp;MIDI Driver:</source>
        <translation>&amp;Драйвер MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="190"/>
        <source>MIDI &amp;Channels:</source>
        <translation>&amp;Каналов MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="203"/>
        <source>Number of MIDI channels</source>
        <translation>Количество каналов MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="151"/>
        <source>Input MIDI driver</source>
        <translation>Драйвер входа MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="807"/>
        <source>Auto Connect &amp;JACK Outputs</source>
        <translation>Автоматически соединяться с &amp;выходом JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="804"/>
        <source>Attempt to connect the JACK outputs to the physical ports</source>
        <translation>Попытка связать выход JACK с физическими портами</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="419"/>
        <location filename="../qsynthSetupForm.ui" line="564"/>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="424"/>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="429"/>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="434"/>
        <source>512</source>
        <translation>512</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="439"/>
        <source>1024</source>
        <translation>1024</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="444"/>
        <source>2048</source>
        <translation>2048</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="449"/>
        <source>4096</source>
        <translation>4096</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="454"/>
        <source>8192</source>
        <translation>8192</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="412"/>
        <source>Period size in bytes (audio buffer size)</source>
        <translation>Размер периода в байтах (размер звукового буфера)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="382"/>
        <source>Sample &amp;Format:</source>
        <translation>&amp;Формат выборок:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="519"/>
        <source>Sample &amp;Rate:</source>
        <translation>&amp;Частота дискретизации:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="539"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="544"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="549"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="554"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="559"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="532"/>
        <source>Period count (number of audio buffers)</source>
        <translation>Число периодов (числов звуковых буферов)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="485"/>
        <source>22050</source>
        <translation>22050</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="490"/>
        <source>44100</source>
        <translation>44100</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="495"/>
        <source>48000</source>
        <translation>48000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="500"/>
        <source>88200</source>
        <translation>88200</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="505"/>
        <source>96000</source>
        <translation>96000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="475"/>
        <source>Sample rate in samples per second (Hz)</source>
        <translation>Частота дискретизации в выборках на секунду (Гц)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="462"/>
        <source>Buffer Cou&amp;nt:</source>
        <translation>Число &amp;буферов:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="405"/>
        <source>Sample format</source>
        <translation>Формат выборок</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="572"/>
        <source>Buffer &amp;Size:</source>
        <translation>&amp;Размер буфера:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="585"/>
        <source>&amp;Audio Driver:</source>
        <translation>&amp;Звуковой драйвер:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="395"/>
        <source>Output audio driver</source>
        <translation>Звуковой драйвер выхода</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="624"/>
        <source>Audio &amp;Channels:</source>
        <translation>Звуковых &amp;каналов:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="698"/>
        <source>&amp;Polyphony:</source>
        <translation>&amp;Полифония:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="666"/>
        <source>Number of stereo audio channels</source>
        <translation>Количество стереофонических звуковых каналов</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="727"/>
        <source>Audio &amp;Groups:</source>
        <translation>Звуковых &amp;групп:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="650"/>
        <source>Number of enabled polyphonic voices</source>
        <translation>Количество включённых полифонических голосов</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="283"/>
        <source>MIDI Client Name ID (ALSA/CoreMidi):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="236"/>
        <source>gm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="241"/>
        <source>gs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="246"/>
        <source>mma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="251"/>
        <source>xs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="637"/>
        <source>Number of audio groups</source>
        <translation>Количество звуковых групп</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="883"/>
        <location filename="../qsynthSetupForm.ui" line="1025"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="901"/>
        <source>Open soundfont file for loading</source>
        <translation>Открыть для загрузки файл SF2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="930"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="956"/>
        <source>&amp;Up</source>
        <translation>&amp;Выше</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="969"/>
        <source>&amp;Down</source>
        <translation>&amp;Ниже</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1030"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1035"/>
        <source>Realtime</source>
        <translation>Реал. время</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1040"/>
        <source>Current</source>
        <translation>Сейчас</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1045"/>
        <source>Default</source>
        <translation>Стандарт.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1050"/>
        <source>Min</source>
        <translation>Мин</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1055"/>
        <source>Max</source>
        <translation>Макс</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1060"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="573"/>
        <location filename="../qsynthSetupForm.cpp" line="832"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="574"/>
        <source>Some settings have been changed.</source>
        <translation>Некоторые настройки изменились.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="575"/>
        <source>Do you want to apply the changes?</source>
        <translation>Вы хотите учесть изменения?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="780"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="785"/>
        <source>Move Up</source>
        <translation>Переместить выше</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="789"/>
        <source>Move Down</source>
        <translation>Переместить ниже</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="815"/>
        <location filename="../qsynthSetupForm.cpp" line="817"/>
        <source>Soundfont files</source>
        <translation>Файлы SF2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="862"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="863"/>
        <source>Failed to add soundfont file</source>
        <translation>Не удалось добавить файл SF2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="865"/>
        <source>Please, check for a valid soundfont file.</source>
        <translation>Проверьте целостность файла SF2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="770"/>
        <source>Open...</source>
        <translation>Открыть...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="833"/>
        <source>Soundfont file already on list</source>
        <translation>Этот файл SF2 уже есть в списке</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="835"/>
        <source>Add anyway?</source>
        <translation>Всё равно добавить?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="51"/>
        <source>Engine &amp;Name:</source>
        <translation>Название &amp;движка:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="64"/>
        <source>Engine display name</source>
        <translation>Отображать имя движка</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="303"/>
        <source>pid</source>
        <translation>pid</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="308"/>
        <location filename="../qsynthSetupForm.ui" line="781"/>
        <source>qsynth</source>
        <translation>qsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="296"/>
        <source>ALSA Sequencer client name identification</source>
        <translation>Идентификация клиента секвенсера ALSA</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="817"/>
        <source>&amp;Multiple JACK Outputs</source>
        <translation>&amp;Несколько выходов JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="814"/>
        <source>Create multiple JACK output ports for channels, groups and effects</source>
        <translation>Создать несколько портов выхода JACK для каналов, групп и эффектов</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="753"/>
        <source>JACK Client Name &amp;ID:</source>
        <translation>&amp;ID клиента JACK:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="776"/>
        <source>fluidsynth</source>
        <translation>fluidsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="766"/>
        <source>JACK client name identification</source>
        <translation>Идентификация клиента JACK</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="856"/>
        <source>Soundfont stack</source>
        <translation>Список файлов SF2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="904"/>
        <source>&amp;Open...</source>
        <translation>&amp;Открыть...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="927"/>
        <source>Remove selected soundfont from stack</source>
        <translation>Удалить файл SF2 из списка</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="953"/>
        <source>Move up selected soundfont towards the top of stack</source>
        <translation>Переместить файл SF2 вверх по списку</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="966"/>
        <source>Move down selected soundfont towards the bottom of stack</source>
        <translation>Переместить файл SF2 вниз по списку</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="362"/>
        <source>Setup</source>
        <translation>Параметры движка</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="775"/>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="34"/>
        <source>Qsynth: Setup</source>
        <translation>Qsynth: Параметры</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="93"/>
        <source>&amp;MIDI</source>
        <translation>&amp;MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="131"/>
        <location filename="../qsynthSetupForm.ui" line="685"/>
        <source>MIDI device name</source>
        <translation>Название устройства MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="161"/>
        <source>MIDI &amp;Device:</source>
        <translation>&amp;Устройство MIDI:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="219"/>
        <source>MIDI &amp;Bank Select mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="229"/>
        <source>MIDI Bank Select mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="358"/>
        <source>&amp;Audio</source>
        <translation>&amp;Звук</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="605"/>
        <source>Audio &amp;Device:</source>
        <translation>З&amp;вуковое устройство:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="841"/>
        <source>&amp;Soundfonts</source>
        <translation>&amp;Файлы SF2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="878"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="888"/>
        <source>Offset</source>
        <translation>Смещение</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="914"/>
        <source>Edit selected soundfont bank offset</source>
        <translation>Изменить выбранное смещение банка SF2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="917"/>
        <source>&amp;Edit</source>
        <translation>&amp;Изменить</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="982"/>
        <source>S&amp;ettings</source>
        <translation>&amp;Сводка</translation>
    </message>
</context>
</TS>
